@@ -26,6 +26,7 @@ import abc
 import collections
 import difflib
 import email.utils
+import heapq
 import os
 import re
 import struct
@@ -40,6 +41,7 @@ from . import ling
 from . import misc
 from . import polib4us
 from . import tags
+from . import xml
 
 from .strformat import c as strformat_c
 
@@ -583,7 +585,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             if project_id_version in {'PACKAGE VERSION', 'PROJECT VERSION'}:
                 self.tag('boilerplate-in-project-id-version', project_id_version)
             else:
-                if not re.compile(r'[^_\d\W]').search(project_id_version):
+                if not re.search(r'[^_\d\W]', project_id_version):
                     self.tag('no-package-name-in-project-id-version', project_id_version)
                 if not re.search(r'[0-9]', project_id_version):
                     self.tag('no-version-in-project-id-version', project_id_version)
@@ -822,6 +824,9 @@ class Checker(object, metaclass=abc.ABCMeta):
         flags = collections.Counter(message.flags)
         wrap = None
         format_flags = collections.defaultdict(dict)
+        range_flags = collections.defaultdict(
+            collections.Counter
+        )
         for flag, n in sorted(flags.items()):
             known_flag = True
             if flag == 'fuzzy':
@@ -838,7 +843,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             elif flag.startswith('range:'):
                 if message.msgid_plural is None:
                     self.tag('range-flag-without-plural-string')
-                match = re.match('([0-9]+)[.][.]([0-9]+)', flag[6:].strip(' \t\r\f\v'))
+                match = re.match('\A([0-9]+)[.][.]([0-9]+)\Z', flag[6:].strip(' \t\r\f\v'))
                 if match is not None:
                     i, j = map(int, match.groups())
                     if i < j:
@@ -851,6 +856,9 @@ class Checker(object, metaclass=abc.ABCMeta):
                         message_repr(message, template='{}:'),
                         flag
                     )
+                else:
+                    range_flags[i, j][flag] += n
+                    n = 0
             elif flag.endswith('-format'):
                 known_flag = False
                 for prefix in 'no-', 'possible-', 'impossible-', '':
@@ -874,6 +882,20 @@ class Checker(object, metaclass=abc.ABCMeta):
                     message_repr(message, template='{}:'),
                     flag
                 )
+        if len(range_flags) > 1:
+            [range1, range2] = heapq.nsmallest(2, range_flags.keys())
+            self.tag('conflicting-message-flags',
+                message_repr(message, template='{}:'),
+                min(range_flags[range1].keys()),
+                min(range_flags[range2].keys()),
+            )
+        elif len(range_flags) == 1:
+            [range_flags] = range_flags.values()
+            if sum(range_flags.values()) > 1:
+                self.tag('duplicate-message-flag',
+                    message_repr(message, template='{}:'),
+                    min(range_flags.keys())
+                )
         positive_format_flags = format_flags['']
         info.formats = frozenset(positive_format_flags)
         for fmt1, flag1 in sorted(positive_format_flags.items()):
@@ -918,6 +940,8 @@ class Checker(object, metaclass=abc.ABCMeta):
             except AttributeError:
                 continue
             method(ctx, message, flags)
+        if re.match('\Atype: Content of: (<{xmlname}>)+\Z'.format(xmlname=xml.name_re), message.comment or ''):
+            self._check_message_xml_format(ctx, message, flags)
 
     def _check_message_c_format(self, ctx, message, flags):
         msgids = [message.msgid]
@@ -1129,6 +1153,25 @@ class Checker(object, metaclass=abc.ABCMeta):
                     tags.safestr(src_arg.type), tags.safestr('({})'.format(src_loc)),
                 )
 
+    def _check_message_xml_format(self, ctx, message, flags):
+        if ctx.encoding is None:
+            return
+        prefix = message_repr(message, template='{}:')
+        try:
+            xml.check_fragment(message.msgid)
+        except xml.SyntaxError as exc:
+            if ctx.is_template:
+                self.tag('malformed-xml', prefix, tags.safestr(exc))
+            return
+        if flags.fuzzy:
+            return
+        if not message.msgstr:
+            return
+        try:
+            xml.check_fragment(message.msgstr)
+        except xml.SyntaxError as exc:
+            self.tag('malformed-xml', prefix, tags.safestr(exc))
+
 __all__ = ['Checker']
 
 def is_header_entry(entry):
