@@ -37,7 +37,7 @@ from . import misc
 from . import paths
 
 # =============
-# Header fields
+# header fields
 # =============
 
 def _read_header_fields():
@@ -53,11 +53,11 @@ def _read_header_fields():
 header_fields = _read_header_fields()
 
 # ==========================
-# Header and message parsing
+# header and message parsing
 # ==========================
 
 is_valid_field_name = re.compile(r'^[\x21-\x39\x3b-\x7e]+$').match
-# http://tools.ietf.org/html/rfc5322#section-3.6.8
+# https://tools.ietf.org/html/rfc5322#section-3.6.8
 
 def parse_header(s):
     lines = s.split('\n')
@@ -74,10 +74,10 @@ def parse_header(s):
 
 search_for_conflict_marker = re.compile(r'^#-#-#-#-#  .+  #-#-#-#-#$', re.MULTILINE).search
 # http://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-tools/src/msgl-cat.c?id=v0.18.3#n590
-# http://www.gnu.org/software/gettext/manual/html_node/Creating-Compendia.html#Creating-Compendia
+# https://www.gnu.org/software/gettext/manual/html_node/Creating-Compendia.html#Creating-Compendia
 
 # ============
-# Plural forms
+# plural forms
 # ============
 
 # http://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-runtime/intl/plural.y?id=v0.18.3#n132
@@ -261,18 +261,19 @@ def parse_date(s):
 epoch = datetime.datetime(1995, 7, 2, tzinfo=datetime.timezone.utc)
 
 # ==============
-# String formats
+# string formats
 # ==============
 
 def _read_string_formats():
     path = os.path.join(paths.datadir, 'string-formats')
-    with open(path, 'rt', encoding='ASCII') as file:
-        fields = [
-            s.rstrip() for s in file
-            if s.rstrip() and not s.startswith('#')
-        ]
-    misc.check_sorted(fields)
-    return frozenset(fields)
+    cp = configparser.ConfigParser(interpolation=None, default_section='')
+    cp.read(path, encoding='ASCII')
+    section = cp['formats']
+    misc.check_sorted(section)
+    return {
+        name: frozenset(examples.split())
+        for name, examples in section.items()
+    }
 
 string_formats = _read_string_formats()
 
