@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012, 2013, 2014 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -25,8 +25,13 @@ miscellanea
 import datetime
 import errno
 import shlex
+import sys
+import types
 
 def is_sorted(iterable):
+    '''
+    is the iterable sorted?
+    '''
     # It's not very efficient, but should be enough for our purposes.
     lst1 = list(iterable)
     lst2 = sorted(lst1)
@@ -36,9 +41,19 @@ class DataIntegrityError(Exception):
     pass
 
 def check_sorted(iterable, exception=DataIntegrityError):
+    '''
+    raise exception if the iterable is not sorted
+    '''
     if not is_sorted(iterable):
         raise exception()
 
+def sorted_vk(d):
+    '''
+    iterate over d.values() in the key order
+    '''
+    for k, v in sorted(d.items()):
+        yield v
+
 class OSRelease(object):
 
     '''
@@ -80,9 +95,12 @@ class OSRelease(object):
         return ident in self._id_like
 
 def utc_now():
-    now = datetime.datetime.now()
-    now = now.replace(tzinfo=datetime.timezone.utc)
-    return now
+    '''
+    timezone-aware variant of datetime.now()
+    '''
+    return datetime.datetime.now(
+        datetime.timezone.utc
+    )
 
 def format_range(rng, *, max):
     last = rng[-1]
@@ -97,4 +115,17 @@ def format_range(rng, *, max):
             break
     return ', '.join(map(str, result))
 
+class Namespace(object):
+    '''
+    simple attribute-based namespace
+    '''
+    def __init__(self, **kwargs):
+        super().__init__()
+        self.__dict__.update(kwargs)
+
+Namespace()  # make pyflakes and coverage.py happy
+
+if sys.version_info >= (3, 3):
+    Namespace = types.SimpleNamespace
+
 # vim:ts=4 sw=4 et
