@@ -56,7 +56,7 @@ def default_encoding_patch():
 # polib.codecs
 # ============
 # Work around a few PO parsing bugs:
-# - newline decoding: http://bugs.debian.org/692283
+# - newline decoding: https://bugs.debian.org/692283
 # - trailing comment parsing: https://bitbucket.org/izi/polib/issue/51
 # - atypical comment parsing
 # - parsing of empty files: https://bitbucket.org/izi/polib/issue/59
@@ -111,8 +111,8 @@ def pofile_find_patch():
 
 # polib.unescape()
 # ================
-# Work around an escape sequence decoding bug
-# <https://bitbucket.org/izi/polib/issue/31>.
+# Work around an escape sequence decoding bug.
+# https://bitbucket.org/izi/polib/issue/31
 
 _escapes_re = re.compile(r''' ( \\
 (?: [ntbrfva]
@@ -172,4 +172,81 @@ def detect_encoding_patch():
     original = polib.detect_encoding
     polib.detect_encoding = detect_encoding
 
+# polib.POEntry.flags
+# ===================
+# Fix flag splitting.
+# polib (<< 1.0.4) incorrectly requires that the flag-splitting comma is
+# followed by a space.
+# https://bitbucket.org/izi/polib/issue/46
+
+@register_patch
+def poentry_flags_patch():
+    def get_flags(self):
+        return self._i18nspector_flags
+    def set_flags(self, flags):
+        self._i18nspector_flags = [
+            flag.strip(' \t\r\f\v')
+            for subflags in flags
+            for flag in subflags.split(',')
+        ]
+    polib.POEntry.flags = property(get_flags, set_flags)
+
+# polib.POEntry.msgstr_plural
+# ===========================
+# Force msgstr_plural keys to be integers.
+# polib (<< 1.0.4) uses strings there instead.
+# https://bitbucket.org/izi/polib/issue/49
+
+class IntDict(dict):
+
+    def __setitem__(self, key, value):
+        super().__setitem__(int(key), value)
+
+    def __getitem__(self, key):
+        return super().__getitem__(int(key))
+
+@register_patch
+def poentry_msgstr_plural_patch():
+    def get_msgstr_plural(self):
+        return self._i18nspector_msgstr_plural
+    def set_msgstr_plural(self, d):
+        self._i18nspector_msgstr_plural = IntDict(d)
+    polib.POEntry.msgstr_plural = property(
+        get_msgstr_plural,
+        set_msgstr_plural,
+    )
+
+# polib._BaseEntry.__init__()
+# ===========================
+# Distinguish between empty and non-existent msgid_plural.
+# Distinguish between empty and non-existent msgstr.
+
+@register_patch
+def base_entry_init_patch():
+    def init(self, *args, **kwargs):
+        original(self, *args, **kwargs)
+        if 'msgid_plural' not in kwargs:
+            self.msgid_plural = None
+        if 'msgstr' not in kwargs:
+            self.msgstr = None
+    original = polib._BaseEntry.__init__
+    polib._BaseEntry.__init__ = init
+
+# polib.POEntry.translated()
+# ==========================
+# Consider the message translated if any msgstr[N] is non-empty.
+
+@register_patch
+def poentry_translated_patch():
+    def translated(self):
+        if self.obsolete:
+            return False
+        if 'fuzzy' in self.flags:
+            return False
+        return (
+            self.msgstr or
+            any(self.msgstr_plural.values())
+        )
+    polib.POEntry.translated = translated
+
 # vim:ts=4 sw=4 et
