@@ -20,9 +20,11 @@
 
 import datetime
 import os
+import time
 
 import nose
 from nose.tools import (
+    assert_almost_equal,
     assert_equal,
     assert_false,
     assert_is_instance,
@@ -68,6 +70,14 @@ class test_check_sorted:
         with assert_raises(M.DataIntegrityError):
             M.check_sorted(iterable)
 
+def test_sorted_vk():
+    lst = ['eggs', 'spam', 'ham']
+    d = dict(enumerate(lst))
+    assert_equal(
+        lst,
+        list(M.sorted_vk(d))
+    )
+
 class test_os_release:
 
     def t(self, path, **like):
@@ -148,11 +158,24 @@ class test_os_release:
             with assert_raises(TypeError):
                 os_release.is_like(None)
 
-def test_utc_now():
-    now = M.utc_now()
-    assert_is_instance(now, datetime.datetime)
-    assert_is_not_none(now.tzinfo)
-    assert_equal(now.tzinfo.utcoffset(now), datetime.timedelta(0))
+class test_utc_now:
+
+    def test_types(self):
+        now = M.utc_now()
+        assert_is_instance(now, datetime.datetime)
+        assert_is_not_none(now.tzinfo)
+        assert_equal(now.tzinfo.utcoffset(now), datetime.timedelta(0))
+
+    @aux.fork_isolation
+    def test_tz_resistance(self):
+        def t(tz):
+            os.environ['TZ'] = tz
+            time.tzset()
+            return M.utc_now()
+        now1 = t('Etc/GMT-4')
+        now2 = t('Etc/GMT+2')
+        tdelta = (now1 - now2).total_seconds()
+        assert_almost_equal(tdelta, 0, places=1)
 
 class test_format_range:
 
@@ -179,4 +202,11 @@ class test_format_range:
     def test_huge(self):
         self.t(5, 42 ** 17, 5, '5, 6, 7, ..., 3937657486715347520027492351')
 
+def test_namespace():
+    ns = M.Namespace()
+    with assert_raises(AttributeError):
+        ns.eggs
+    ns.eggs = 37
+    assert_equal(ns.eggs, 37)
+
 # vim:ts=4 sw=4 et
